@@ -7,7 +7,7 @@ RDF::Trine - An RDF Framework for Perl
 
 =head1 VERSION
 
-This document describes RDF::Trine version 0.136
+This document describes RDF::Trine version 0.139
 
 =head1 SYNOPSIS
 
@@ -48,24 +48,28 @@ use Module::Load::Conditional qw[can_load];
 our ($debug, @ISA, $VERSION, @EXPORT_OK);
 BEGIN {
 	$debug		= 0;
-	$VERSION	= '0.136';
+	$VERSION	= '0.139';
 	
 	require Exporter;
 	@ISA		= qw(Exporter);
 	@EXPORT_OK	= qw(iri blank literal variable statement store UNION_GRAPH NIL_GRAPH);
 	
-	can_load( modules => {
-		'RDF::Redland'					=> undef,
-		'RDF::Trine::Store::Redland'	=> undef,
-		'RDF::Trine::Parser::Redland'	=> undef,
-	} );
+	unless ($ENV{RDFTRINE_NO_REDLAND}) {
+		can_load( modules => {
+			'RDF::Redland'					=> undef,
+			'RDF::Trine::Store::Redland'	=> undef,
+			'RDF::Trine::Parser::Redland'	=> undef,
+		} );
+	}
 }
 
 use constant UNION_GRAPH	=> 'tag:gwilliams@cpan.org,2010-01-01:RT:ALL';
 use constant NIL_GRAPH		=> 'tag:gwilliams@cpan.org,2010-01-01:RT:NIL';
 
 use Log::Log4perl qw(:easy);
-Log::Log4perl->easy_init($ERROR);
+if (! Log::Log4perl::initialized() ) {
+    Log::Log4perl->easy_init($ERROR);
+}
 
 use RDF::Trine::Graph;
 use RDF::Trine::Parser;
@@ -185,7 +189,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2010 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
