@@ -7,7 +7,7 @@ RDF::Trine::Statement::Quad - Class for quads and quad patterns
 
 =head1 VERSION
 
-This document describes RDF::Trine::Statement::Quad version 0.137
+This document describes RDF::Trine::Statement::Quad version 0.139
 
 =cut
 
@@ -19,12 +19,13 @@ no warnings 'redefine';
 use base qw(RDF::Trine::Statement);
 
 use Scalar::Util qw(blessed);
+use Carp qw(croak);
 
 ######################################################################
 
 our ($VERSION);
 BEGIN {
-	$VERSION	= '0.137';
+	$VERSION	= '0.139';
 }
 
 ######################################################################
@@ -161,7 +162,7 @@ sub from_redland {
 						: undef;
 			return RDF::Trine::Node::Literal->new( $node->literal_value, $lang, $dt );
 		} else {
-			die;
+			croak 'Unknown node type in statement conversion';
 		}
 	};
 	
@@ -188,7 +189,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2010 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
