@@ -4,7 +4,7 @@ RDF::Trine::Store::Hexastore - RDF store implemented with the hexastore index
 
 =head1 VERSION
 
-This document describes RDF::Trine::Store::Hexastore version 0.137
+This document describes RDF::Trine::Store::Hexastore version 0.139
 
 =head1 SYNOPSIS
 
@@ -30,6 +30,8 @@ use RDF::Trine::Error;
 use List::Util qw(first);
 use Scalar::Util qw(refaddr reftype blessed);
 use Storable qw(nstore retrieve);
+use Carp qw(croak);
+use Time::HiRes qw ( time );
 
 use constant NODES		=> qw(subject predicate object);
 use constant NODEMAP	=> { subject => 0, predicate => 1, object => 2, context => 3 };
@@ -43,7 +45,7 @@ use constant OTHERNODES	=> {
 
 our $VERSION;
 BEGIN {
-	$VERSION	= "0.137";
+	$VERSION	= "0.139";
 	my $class	= __PACKAGE__;
 	$RDF::Trine::Store::STORE_CLASSES{ $class }	= $VERSION;
 }
@@ -112,9 +114,9 @@ sub new {
 }
 
 sub _new_with_string {
-    my ($self, $config) = @_;
-    my ($filename) = $config =~ m/file=(.+)$/; # TODO: It has a Storable part too, for later use.
-    return $self->load($filename);
+	my ($self, $config) = @_;
+	my ($filename) = $config =~ m/file=(.+)$/; # TODO: It has a Storable part too, for later use.
+	return $self->load($filename);
 }
 
 # TODO: Refactor, almost identical to Memory
@@ -271,10 +273,10 @@ sub get_statements {
 		my $rev	= 0;
 		if (@orderby) {
 			$rev	= 1 if ($orderby[1] eq 'DESC');
- 			my $sortkey	= $variable_map{ $orderby[0] };
- 			if ($sortkey ne $ukeys[0]) {
- 				@ukeys	= reverse(@ukeys);
- 			}
+			my $sortkey	= $variable_map{ $orderby[0] };
+			if ($sortkey ne $ukeys[0]) {
+				@ukeys	= reverse(@ukeys);
+			}
 		}
 		
 		my $index	= $self->_index_from_pair( $self->_index_root, @keys );
@@ -285,7 +287,7 @@ sub get_statements {
 		my $ukey1;
 		my $sub		= sub {
 			while (0 == scalar(@local_list)) {
- 				return undef unless (scalar(@ukeys1));
+				return undef unless (scalar(@ukeys1));
 				$ukey1		= shift(@ukeys1);
 #				warn '>>>>>>>>> ' . Dumper( $ukeys[0], $ukey1, $data );
 				my $list	= $self->_index_from_pair( $index, $ukeys[0], $ukey1 );
@@ -322,12 +324,12 @@ sub get_statements {
 		
 		my $rev	= 0;
 		my (@order_keys, $final_key);
- 		if (@orderby) {
+		if (@orderby) {
 			$rev	= 1 if ($orderby[1] eq 'DESC');
- 			my $sortkey	= $variable_map{ $orderby[0] };
- 			my @nodes	= ($sortkey, grep { $_ ne $sortkey } NODES);
- 			@order_keys	= @nodes[0,1];
- 			$final_key	= $nodes[2];
+			my $sortkey	= $variable_map{ $orderby[0] };
+			my @nodes	= ($sortkey, grep { $_ ne $sortkey } NODES);
+			@order_keys	= @nodes[0,1];
+			$final_key	= $nodes[2];
 		} else {
 			$final_key	= 'object';
 			@order_keys	= qw(subject predicate);
@@ -409,45 +411,43 @@ sub get_pattern {
 			my $i1	= $self->SUPER::get_pattern( RDF::Trine::Pattern->new( $t1 ), undef, orderby => [ $shrkey => 'ASC' ] );
 			my $i2	= $self->SUPER::get_pattern( RDF::Trine::Pattern->new( $t2 ), undef, orderby => [ $shrkey => 'ASC' ] );
 			
-			
-			$i1->next;
-			$i2->next;
-			
+			my $i1current	= $i1->next;
+			my $i2current	= $i2->next;
 			my @results;
-			while (not($i1->finished) and not($i2->finished)) {
-				my $i1cur	= $i1->current->{ $shrkey };
-				my $i2cur	= $i2->current->{ $shrkey };
-				if ($i1->current->{ $shrkey }->equal( $i2->current->{ $shrkey } )) {
+			while (defined($i1current) and defined($i2current)) {
+				my $i1cur	= $i1current->{ $shrkey };
+				my $i2cur	= $i2current->{ $shrkey };
+				if ($i1current->{ $shrkey }->equal( $i2current->{ $shrkey } )) {
 					my @matching_i2_rows;
-					my $match_value	= $i1->current->{ $shrkey };
-					while ($match_value->equal( $i2->current->{ $shrkey } )) {
-						push( @matching_i2_rows, $i2->current );
-						unless ($i2->next) {
+					my $match_value	= $i1current->{ $shrkey };
+					while ($match_value->equal( $i2current->{ $shrkey } )) {
+						push( @matching_i2_rows, $i2current );
+						unless ($i2current = $i2->next) {
 #							warn "no more from i2";
 							last;
 						}
 					}
 					
-					while ($match_value->equal( $i1->current->{ $shrkey } )) {
+					while ($match_value->equal( $i1current->{ $shrkey } )) {
 						foreach my $i2_row (@matching_i2_rows) {
-							my $new	= $self->_join( $i1->current, $i2_row );
+							my $new	= $self->_join( $i1current, $i2_row );
 							push( @results, $new );
 						}
-						unless ($i1->next) {
+						unless ($i1current = $i1->next) {
 #							warn "no more from i1";
 							last;
 						}
 					}
-				} elsif ($i1->current->{ $shrkey }->compare( $i2->current->{ $shrkey } ) == -1) {
-					my $i1v	= $i1->current->{ $shrkey };
-					my $i2v	= $i2->current->{ $shrkey };
+				} elsif ($i1current->{ $shrkey }->compare( $i2current->{ $shrkey } ) == -1) {
+					my $i1v	= $i1current->{ $shrkey };
+					my $i2v	= $i2current->{ $shrkey };
 					warn "keys don't match: $i1v <=> $i2v\n";
-					$i1->next;
-				} else { # ($i1->current->{ $shrkey } > $i2->current->{ $shrkey })
-					my $i1v	= $i1->current->{ $shrkey };
-					my $i2v	= $i2->current->{ $shrkey };
+					$i1current	= $i1->next;
+				} else { # ($i1current->{ $shrkey } > $i2current->{ $shrkey })
+					my $i1v	= $i1current->{ $shrkey };
+					my $i2v	= $i2current->{ $shrkey };
 					warn "keys don't match: $i1v <=> $i2v\n";
-					$i2->next;
+					$i2current	= $i2->next;
 				}
 			}
 			return RDF::Trine::Iterator::Bindings->new( \@results, [ $bgp->referenced_variables ] );
@@ -514,7 +514,7 @@ sub _join {
 =cut
 
 sub get_contexts {
-	die;
+	croak "Contexts not supported for the Hexastore store";
 }
 
 =item C<< add_statement ( $statement [, $context] ) >>
@@ -543,6 +543,7 @@ sub add_statement {
 	}
 	if ($added) {
 		$self->{ size }++;
+		$self->{etag} = time;
 	}
 }
 
@@ -578,6 +579,7 @@ sub remove_statement {
 	
 	if ($removed) {
 		$self->{ size }--;
+		$self->{etag} = time;
 	}
 }
 
@@ -585,6 +587,17 @@ sub remove_statement {
 
 Removes the specified C<$statement> from the underlying model.
 
+=item C<< etag >>
+
+Returns an Etag suitable for use in an HTTP Header.
+
+=cut
+
+sub etag {
+	return $_[0]->{etag};
+}
+
+
 =item C<< nuke >>
 
 Permanently removes all the data in the store.
@@ -592,13 +605,14 @@ Permanently removes all the data in the store.
 =cut
 
 sub nuke {
-    my $self = shift;
-    $self->{data} = $self->_new_index_page;
-    $self->{node2id} = {};
-    $self->{id2node} = {};
-    $self->{next_id} = 1;
-    $self->{size} = 0;
-    return $self;
+	my $self = shift;
+	$self->{data} = $self->_new_index_page;
+	$self->{node2id} = {};
+	$self->{id2node} = {};
+	$self->{next_id} = 1;
+	$self->{size} = 0;
+	$self->{etag} = time;
+	return $self;
 }
 
 
@@ -866,7 +880,7 @@ Gregory Todd Williams  C<< <gwilliams@cpan.org> >>
 
 =head1 COPYRIGHT
 
-Copyright (c) 2006-2010 Gregory Todd Williams. This
+Copyright (c) 2006-2012 Gregory Todd Williams. This
 program is free software; you can redistribute it and/or modify it under
 the same terms as Perl itself.
 
